@@ -14,7 +14,7 @@ __author__ = (
     "Mark Harviston <mark.harviston@gmail.com>, "
     "Arve Knudsen <arve.knudsen@gmail.com>",
 )
-__version__ = "0.20.0"
+__version__ = "0.22.0"
 __url__ = "https://github.com/CabbageDevelopment/qasync"
 __license__ = "BSD"
 __all__ = ["QEventLoop", "QThreadExecutor", "asyncSlot", "asyncClose"]
@@ -85,28 +85,28 @@ QtCore = importlib.import_module(QtModuleName + ".QtCore", package=QtModuleName)
 QtGui = importlib.import_module(QtModuleName + ".QtGui", package=QtModuleName)
 
 if QtModuleName == "PyQt5":
-    from PyQt5 import QtCore
+    from PyQt5 import QtWidgets
     from PyQt5.QtCore import pyqtSlot as Slot
 
-    QApplication = QtCore.QCoreApplication
+    QApplication = QtWidgets.QApplication
 
 elif QtModuleName == "PyQt6":
-    from PyQt6 import QtCore
+    from PyQt6 import QtWidgets
     from PyQt6.QtCore import pyqtSlot as Slot
 
-    QApplication = QtCore.QCoreApplication
+    QApplication = QtWidgets.QApplication
 
 elif QtModuleName == "PySide2":
-    from PySide2 import QtCore
+    from PySide2 import QtWidgets
     from PySide2.QtCore import Slot
 
-    QApplication = QtCore.QCoreApplication
+    QApplication = QtWidgets.QApplication
 
 elif QtModuleName == "PySide6":
-    from PySide6 import QtCore
+    from PySide6 import QtWidgets
     from PySide6.QtCore import Slot
 
-    QApplication = QtCore.QCoreApplication
+    QApplication = QtWidgets.QApplication
 
 from ._common import with_logger  # noqa
 
@@ -539,7 +539,10 @@ class _QEventLoop:
             existing.activated["int"].disconnect()
             # will get overwritten by the assignment below anyways
 
-        notifier = QtCore.QSocketNotifier(fd, QtCore.QSocketNotifier.Type.Write)
+        notifier = QtCore.QSocketNotifier(
+            _fileno(fd),
+            QtCore.QSocketNotifier.Type.Write,
+        )
         notifier.setEnabled(True)
         self.__log_debug("Adding writer callback for file descriptor %s", fd)
         notifier.activated["int"].connect(
